@@ -15,7 +15,7 @@ from django.core.files.base import ContentFile
 
 import requests
 
-from .widgets import FileOrURLWidget
+from .widgets import MutuallyExclusiveRadioWidget, FileOrURLWidget
 
 
 __all__ = ['MutuallyExclusiveValueField', 'FileOrURLField']
@@ -25,6 +25,13 @@ class MutuallyExclusiveValueField(MultiValueField):
     too_many_values_error = 'Exactly One field is required, no more'
     empty_values = EMPTY_VALUES
 
+    def __init__(self, fields=(), *args, **kwargs):
+        if 'widget' not in kwargs:
+            kwargs['widget'] = MutuallyExclusiveRadioWidget(widgets=[
+                field.widget for field in fields])
+        super(MutuallyExclusiveValueField, self).__init__(
+            fields, *args, **kwargs)
+
     def clean(self, value):
         """
         Validates every value in the given list. A value is validated against
@@ -35,12 +42,8 @@ class MutuallyExclusiveValueField(MultiValueField):
 
         example to use directy (instead of using FileOrURLField):
             MutuallyExclusiveValueField(
-                fields=(forms.IntegerField(), forms.IntegerField()),
-                widget=MutuallyExclusiveRadioWidget(widgets=[
-                        forms.Select(choices=[(1,1), (2,2)]),
-                        forms.TextInput(attrs={'placeholder':
-                                               'Enter a number'}),
-                    ]))
+                fields=(forms.TypedChoiceField(choices=[(1,1), (2,2)], coerce=int),
+                        forms.IntegerField()))
         """
         clean_data = []
         errors = ErrorList()
